// pages/index.tsx
import Head from 'next/head';
import Image from 'next/image';
import ScrollableCards from '../components/ScrollAbleCards'; // Import ScrollableCards component

export default function VisaInfo() {
  return (
    <main className="w-full m-4 sm:px-6 lg:px-8">
      <h1 className="text-2xl font-bold mb-2">
        Our Packages <span className="text-emerald-600">Till Now</span>
      </h1>
      <p className="text-gray-600 mb-8">Dedicated visa experts</p>

      {/* Uncomment this section if you need the search bar */}
      {/* <div className="mb-8">
        <div className="flex items-center bg-white rounded-full shadow-md overflow-hidden">
          <input
            type="text"
            placeholder="Where to, captain?"
            className="w-full py-3 px-6 focus:outline-none"
          />
          <button className="bg-blue-600 text-white p-3 transition hover:bg-blue-700">
            <svg
              className="w-6 h-6"
              fill="none"
              stroke="currentColor"
              viewBox="0 0 24 24"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                strokeLinecap="round"
                strokeLinejoin="round"
                strokeWidth={2}
                d="M21 21l-6-6m2-5a7 7 0 11-14 0 7 7 0 0114 0z"
              />
            </svg>
          </button>
        </div>
      </div> */}

      <div className="flex space-x-4 mb-8 overflow-x-auto no-scrollbar">
        {['Popular', 'Visa in a week', 'Easy Visa', 'Schengen Visa', 'Visa Free', 'Season'].map((item) => (
          <button
            key={item}
            className="px-4 py-2 bg-white rounded-full text-gray-600 hover:bg-gray-200 transition whitespace-nowrap"
          >
            {item}
          </button>
        ))}
      </div>

      <ScrollableCards title="Visa Information">
        {[
          { name: 'UAE', type: 'eVisa', issued: '193 issued within 2 days', image: '/uae.jpg' },
          { name: 'Singapore', type: 'eVisa', issued: '126 issued recently', image: '/singapore.jpg' },
          { name: 'Japan', type: 'Sticker Visa', issued: '59 issued within 7 days', image: '/japan.jpg' },
          { name: 'Vietnam', type: 'eVisa', issued: '178 issued within 3 days', image: '/vietnam.jpeg' },
          { name: 'Schengen', type: 'eVisa', issued: '390 issued within 4 days', image: '/world.jpg' },
        ].map((country) => (
          <div
            key={country.name}
            className="min-w-[250px] mr-5 bg-white rounded-lg overflow-hidden shadow-lg transition transform hover:scale-105"
          >
            <div className="relative h-48">
              <Image src={country.image} alt={country.name} layout="fill" objectFit="cover" />
              <div className="absolute top-2 left-2 bg-yellow-400 text-xs font-semibold px-2 py-1 rounded-full shadow">
                {country.issued}
              </div>
            </div>
            <div className="p-4">
              <h3 className="font-bold text-lg">{country.name}</h3>
              <p className="text-sm text-gray-600">{country.type}</p>
              <div className="mt-4 flex justify-between items-center">
                <span className="text-sm">Per person</span>
                <span className="text-sm">Get Visa in</span>
              </div>
              <div className="flex justify-between items-center mt-2">
                <span className="font-bold">৳2999</span>
                <span className="text-green-500">2 days</span>
              </div>
            </div>
          </div>
        ))}
      </ScrollableCards>
    </main>
  );
}
